@@ -8,7 +8,7 @@ TAopt <- function(OF, algo = list(), ...) {
                   vT = NULL,  ## threshold sequence
                   neighbour = NULL,
                   printDetail = TRUE,
-                  printBar = TRUE,
+                  printBar = interactive(),
                   stepUp = 0L,
                   scale = 1,
                   drop0 = FALSE,
